@@ -57,15 +57,14 @@ import fr.gouv.vitamui.commons.api.exception.BadRequestException;
 import fr.gouv.vitamui.commons.vitam.api.dto.FacetBucketDto;
 import fr.gouv.vitamui.commons.vitam.api.dto.FacetResultsDto;
 import fr.gouv.vitamui.commons.vitam.api.dto.VitamUISearchResponseDto;
-import org.apache.commons.lang.StringUtils;
+import jakarta.validation.constraints.NotNull;
+import org.apache.commons.lang3.StringUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.context.annotation.Lazy;
 import org.springframework.stereotype.Service;
 import org.springframework.util.CollectionUtils;
 
-import javax.validation.constraints.NotNull;
 import java.time.LocalDateTime;
 import java.time.format.DateTimeParseException;
 import java.util.ArrayList;
@@ -86,6 +85,7 @@ import static fr.gouv.vitamui.commons.api.utils.ArchiveSearchConsts.CriteriaCate
 import static fr.gouv.vitamui.commons.api.utils.ArchiveSearchConsts.CriteriaDataType.STRING;
 import static fr.gouv.vitamui.commons.api.utils.ArchiveSearchConsts.CriteriaMgtRulesCategory;
 import static fr.gouv.vitamui.commons.api.utils.ArchiveSearchConsts.CriteriaOperators.EQ;
+import static fr.gouv.vitamui.commons.api.utils.ArchiveSearchConsts.DEFAULT_FACET_RULES_SIZE;
 import static fr.gouv.vitamui.commons.api.utils.ArchiveSearchConsts.FACETS_COUNT_WITHOUT_RULES;
 import static fr.gouv.vitamui.commons.api.utils.ArchiveSearchConsts.FACETS_EXPIRED_RULES_COMPUTED;
 import static fr.gouv.vitamui.commons.api.utils.ArchiveSearchConsts.FACETS_FINAL_ACTION_COMPUTED;
@@ -107,7 +107,7 @@ import static fr.gouv.vitamui.commons.api.utils.MetadataSearchCriteriaUtils.crea
 import static fr.gouv.vitamui.commons.api.utils.MetadataSearchCriteriaUtils.mapRequestToDslQuery;
 
 /**
- * Archive-Search facets Internal service .
+ * Archive-Search facets service .
  */
 @Service
 public class ArchiveSearchFacetsService {
@@ -124,7 +124,6 @@ public class ArchiveSearchFacetsService {
     private final ArchiveSearchService archiveSearchService;
     private final ObjectMapper objectMapper;
 
-    @Autowired
     public ArchiveSearchFacetsService(
         final @Lazy ArchiveSearchService archiveSearchService,
         final ObjectMapper objectMapper
@@ -194,7 +193,7 @@ public class ArchiveSearchFacetsService {
                 FacetHelper.terms(
                     FACETS_RULES_COMPUTED_NUMBER + "_" + category.name(),
                     computedRulesIdentifierMapping,
-                    100,
+                    DEFAULT_FACET_RULES_SIZE,
                     FacetOrder.ASC
                 )
             );
@@ -324,7 +323,7 @@ public class ArchiveSearchFacetsService {
         VitamContext vitamContext
     ) throws InvalidCreateOperationException, VitamClientException, JsonProcessingException {
         List<FacetResultsDto> facetResults = new ArrayList<>();
-        if (searchQuery.isComputeFacets()) {
+        if (searchQuery.isComputeMgtRulesFacets()) {
             try {
                 LOGGER.debug("Start computing facets for units with computed inheritance rules  ");
                 List<CriteriaCategory> categories = List.of(
