@@ -74,8 +74,9 @@ import fr.gouv.vitamui.commons.vitam.api.dto.VersionsDto;
 import fr.gouv.vitamui.commons.vitam.api.dto.VitamUISearchResponseDto;
 import fr.gouv.vitamui.commons.vitam.api.model.UnitTypeEnum;
 import fr.gouv.vitamui.iam.security.service.SecurityService;
+import jakarta.ws.rs.core.Response;
 import lombok.Getter;
-import org.apache.commons.lang.StringUtils;
+import org.apache.commons.lang3.StringUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.springframework.beans.factory.annotation.Autowired;
@@ -86,7 +87,6 @@ import org.springframework.stereotype.Service;
 import org.springframework.util.CollectionUtils;
 import reactor.core.publisher.Mono;
 
-import javax.ws.rs.core.Response;
 import java.io.IOException;
 import java.util.Arrays;
 import java.util.List;
@@ -105,7 +105,7 @@ import static java.util.Objects.nonNull;
 import static org.apache.commons.lang3.ObjectUtils.isEmpty;
 
 /**
- * Archive-Search Internal service communication with VITAM.
+ * Archive-Search service communication with VITAM.
  */
 @Getter
 @Service
@@ -215,7 +215,7 @@ public class ArchiveSearchService {
                     archiveSearchFacetsService.fillManagementRulesFacets(searchQuery, trackTotalHits, vitamContext)
                 );
         } catch (UnexpectedSettingsException e) {
-            if (!searchQuery.isComputeFacets()) {
+            if (!searchQuery.isComputeMgtRulesFacets()) {
                 LOGGER.error(
                     "Could not compute facets,the setting track total hits is not allowed in vitam, we return units without facets"
                 );
