@@ -79,4 +79,7 @@ public class CollectProjectDto extends IdDto {
     private String createdOn;
     private String lastModifyOn;
     private Boolean automaticIngest;
+    private String archivingSystemId;
+    private Integer archivingSystemTenant;
+    private Boolean connectedToArchivingSystem;
 }
