@@ -38,13 +38,14 @@ package fr.gouv.vitamui.iam.common.dto;
 
 import fr.gouv.vitamui.commons.api.domain.CustomerIdDto;
 import fr.gouv.vitamui.iam.common.enums.AuthnRequestBindingEnum;
+import jakarta.validation.constraints.NotNull;
+import jakarta.validation.constraints.Size;
 import lombok.EqualsAndHashCode;
 import lombok.Getter;
 import lombok.Setter;
 import lombok.ToString;
 
-import javax.validation.constraints.NotNull;
-import javax.validation.constraints.Size;
+import java.io.Serial;
 import java.util.List;
 import java.util.Map;
 
@@ -65,6 +66,7 @@ public class IdentityProviderDto extends CustomerIdDto {
     /**
      *
      */
+    @Serial
     private static final long serialVersionUID = 2372968720503585884L;
 
     // Common data to all providers
