@@ -45,11 +45,11 @@ import fr.gouv.vitamui.commons.mongo.service.SequenceGeneratorService;
 import fr.gouv.vitamui.commons.rest.RestExceptionHandler;
 import fr.gouv.vitamui.commons.rest.client.BaseRestClientFactory;
 import fr.gouv.vitamui.commons.rest.client.configuration.RestClientConfiguration;
-import fr.gouv.vitamui.commons.rest.configuration.SwaggerConfiguration;
 import fr.gouv.vitamui.commons.security.client.config.password.PasswordConfiguration;
 import fr.gouv.vitamui.commons.security.client.password.PasswordValidator;
 import fr.gouv.vitamui.commons.vitam.api.access.LogbookService;
 import fr.gouv.vitamui.commons.vitam.api.administration.AccessContractCommonService;
+import fr.gouv.vitamui.commons.vitam.api.administration.ConfigurationService;
 import fr.gouv.vitamui.commons.vitam.api.administration.IngestContractCommonService;
 import fr.gouv.vitamui.commons.vitam.api.config.VitamAccessConfig;
 import fr.gouv.vitamui.commons.vitam.api.config.VitamAdministrationConfig;
@@ -62,7 +62,6 @@ import fr.gouv.vitamui.iam.security.service.SecurityService;
 import fr.gouv.vitamui.iam.server.application.service.ApplicationService;
 import fr.gouv.vitamui.iam.server.cas.service.CasService;
 import fr.gouv.vitamui.iam.server.common.service.AddressService;
-import fr.gouv.vitamui.iam.server.configuration.ConfigurationService;
 import fr.gouv.vitamui.iam.server.customer.config.CustomerInitConfig;
 import fr.gouv.vitamui.iam.server.customer.converter.CustomerConverter;
 import fr.gouv.vitamui.iam.server.customer.dao.CustomerRepository;
@@ -108,8 +107,8 @@ import fr.gouv.vitamui.iam.server.user.service.UserEmailService;
 import fr.gouv.vitamui.iam.server.user.service.UserExportService;
 import fr.gouv.vitamui.iam.server.user.service.UserInfoService;
 import fr.gouv.vitamui.iam.server.user.service.UserService;
-import fr.gouv.vitamui.security.client.ContextRestClient;
-import fr.gouv.vitamui.security.client.SecurityRestClientFactory;
+import fr.gouv.vitamui.security.openapiclient.ContextsApi;
+import fr.gouv.vitamui.security.openapiclient.SecurityApiClientsFactory;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.boot.context.properties.ConfigurationProperties;
 import org.springframework.boot.context.properties.EnableConfigurationProperties;
@@ -123,14 +122,13 @@ import org.springframework.data.mongodb.core.MongoOperations;
 import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
 import org.springframework.security.crypto.password.PasswordEncoder;
 import org.springframework.web.multipart.MultipartResolver;
-import org.springframework.web.multipart.commons.CommonsMultipartResolver;
 import org.springframework.web.multipart.support.MultipartFilter;
+import org.springframework.web.multipart.support.StandardServletMultipartResolver;
 
 @Configuration
 @Import(
     {
         RestExceptionHandler.class,
-        SwaggerConfiguration.class,
         WebSecurityConfig.class,
         VitamAccessConfig.class,
         VitamAdministrationConfig.class,
@@ -142,7 +140,7 @@ public class ApiIamServerConfig extends AbstractContextConfiguration {
 
     @Bean
     public MultipartResolver multipartResolver() {
-        return new CommonsMultipartResolver();
+        return new StandardServletMultipartResolver();
     }
 
     @Bean
@@ -175,16 +173,16 @@ public class ApiIamServerConfig extends AbstractContextConfiguration {
     }
 
     @Bean
-    public SecurityRestClientFactory securityRestClientFactory(
+    public SecurityApiClientsFactory securityApiClientsFactory(
         final RestTemplateBuilder restTemplateBuilder,
         final ApiIamApplicationProperties apiIamApplicationProperties
     ) {
-        return new SecurityRestClientFactory(apiIamApplicationProperties.getSecurityClient(), restTemplateBuilder);
+        return new SecurityApiClientsFactory(apiIamApplicationProperties.getSecurityClient(), restTemplateBuilder);
     }
 
     @Bean
-    public ContextRestClient contextCrudRestClient(final SecurityRestClientFactory securityRestClientFactory) {
-        return securityRestClientFactory.getContextRestClient();
+    public ContextsApi contextsApi(final SecurityApiClientsFactory securityApiClientsFactory) {
+        return securityApiClientsFactory.getContextsApi();
     }
 
     @Bean
@@ -196,30 +194,15 @@ public class ApiIamServerConfig extends AbstractContextConfiguration {
         return new IamUserAuthentificationService(userService, tokenRepository, subrogationRepository);
     }
 
-    @Bean
-    public InternalApiAuthenticationProvider internalApiAuthenticationProvider(
-        IamUserAuthentificationService iamUserAuthentificationService
-    ) {
-        return new InternalApiAuthenticationProvider(iamUserAuthentificationService);
-    }
-
-    @Bean
-    public ExternalApiAuthenticationProvider externalApiAuthenticationProvider(
-        SecurityRestClientFactory securityRestClientFactory,
-        IamUserAuthentificationService iamAuthentificationService
-    ) {
-        return new ExternalApiAuthenticationProvider(
-            securityRestClientFactory.getContextRestClient(),
-            iamAuthentificationService
-        );
-    }
-
     @Bean
     public ApiAuthenticationProvider apiAuthenticationProvider(
-        final InternalApiAuthenticationProvider internalApiAuthenticationProvider,
-        final ExternalApiAuthenticationProvider externalApiAuthenticationProvider
+        IamUserAuthentificationService iamUserAuthentificationService,
+        ContextsApi contextsApi
     ) {
-        return new ApiAuthenticationProvider(internalApiAuthenticationProvider, externalApiAuthenticationProvider);
+        return new ApiAuthenticationProvider(
+            new InternalApiAuthenticationProvider(iamUserAuthentificationService),
+            new ExternalApiAuthenticationProvider(contextsApi, iamUserAuthentificationService)
+        );
     }
 
     @Bean
@@ -262,7 +245,7 @@ public class ApiIamServerConfig extends AbstractContextConfiguration {
     public CustomerService customerCrudService(
         final SequenceGeneratorService sequenceGeneratorService,
         final CustomerRepository customerRepository,
-        final OwnerService internalOwnerService,
+        final OwnerService ownerService,
         final UserService userService,
         final SecurityService securityService,
         final AddressService addressService,
@@ -274,7 +257,7 @@ public class ApiIamServerConfig extends AbstractContextConfiguration {
         return new CustomerService(
             sequenceGeneratorService,
             customerRepository,
-            internalOwnerService,
+            ownerService,
             userService,
             securityService,
             addressService,
@@ -336,17 +319,13 @@ public class ApiIamServerConfig extends AbstractContextConfiguration {
         final TenantRepository tenantRepository,
         final CustomerRepository customerRepository,
         final OwnerRepository ownerRepository,
-        final GroupRepository groupRepository,
         final ProfileRepository profileRepository,
-        final UserRepository userRepository,
-        final GroupService internalGroupService,
-        final UserService internalUserService,
-        final OwnerService internalOwnerService,
-        final ProfileService internalProfileService,
+        final GroupService groupService,
+        final UserService userService,
+        final OwnerService ownerService,
         final SecurityService securityService,
         final IamLogbookService iamLogbookService,
         final TenantConverter tenantConverter,
-        final AccessContractCommonService accessContractCommonService,
         final InitVitamTenantService initVitamTenantService,
         final LogbookService logbookService,
         final CustomerInitConfig customerInitConfig,
@@ -360,9 +339,9 @@ public class ApiIamServerConfig extends AbstractContextConfiguration {
             customerRepository,
             ownerRepository,
             profileRepository,
-            internalGroupService,
-            internalUserService,
-            internalOwnerService,
+            groupService,
+            userService,
+            ownerService,
             securityService,
             iamLogbookService,
             tenantConverter,
@@ -389,9 +368,7 @@ public class ApiIamServerConfig extends AbstractContextConfiguration {
         final TenantRepository tenantRepository,
         final SecurityService securityService,
         final CustomerRepository customerRepository,
-        final ProfileRepository profilRepository,
         final GroupService groupService,
-        final GroupRepository groupRepository,
         final IamLogbookService iamLogbookService,
         final UserConverter userConverter,
         final MongoTransactionManager mongoTransactionManager,
@@ -449,7 +426,7 @@ public class ApiIamServerConfig extends AbstractContextConfiguration {
         final SequenceGeneratorService sequenceGeneratorService,
         final GroupRepository groupRepository,
         final CustomerRepository customerRepository,
-        final ProfileService internalProfileService,
+        final ProfileService profileService,
         final UserRepository userRepository,
         final SecurityService securityService,
         final TenantRepository tenantRepository,
@@ -462,7 +439,7 @@ public class ApiIamServerConfig extends AbstractContextConfiguration {
             sequenceGeneratorService,
             groupRepository,
             customerRepository,
-            internalProfileService,
+            profileService,
             userRepository,
             securityService,
             tenantRepository,
@@ -600,11 +577,10 @@ public class ApiIamServerConfig extends AbstractContextConfiguration {
 
     @Bean
     public ConfigurationService configurationService(
-        final SecurityService securityService,
         final AdminExternalClient adminExternalClient,
         final ObjectMapper objectMapper
     ) {
-        return new ConfigurationService(securityService, adminExternalClient, objectMapper);
+        return new ConfigurationService(adminExternalClient, objectMapper);
     }
 
     @Bean
