@@ -64,15 +64,15 @@ import fr.gouv.vitamui.commons.mongo.CustomSequencesConstants;
 import fr.gouv.vitamui.commons.mongo.service.SequenceGeneratorService;
 import fr.gouv.vitamui.commons.utils.JsonUtils;
 import fr.gouv.vitamui.commons.vitam.api.access.LogbookService;
+import fr.gouv.vitamui.commons.vitam.api.administration.ConfigurationService;
 import fr.gouv.vitamui.commons.vitam.api.dto.LogbookOperationsCommonResponseDto;
 import fr.gouv.vitamui.commons.vitam.api.util.VitamRestUtils;
 import fr.gouv.vitamui.iam.common.enums.Application;
 import fr.gouv.vitamui.iam.security.service.SecurityService;
-import fr.gouv.vitamui.iam.server.common.ApiIamExternalConstants;
+import fr.gouv.vitamui.iam.server.common.ApiIamConstants;
 import fr.gouv.vitamui.iam.server.common.domain.MongoDbCollections;
 import fr.gouv.vitamui.iam.server.common.domain.SequencesConstants;
 import fr.gouv.vitamui.iam.server.common.utils.EntityFactory;
-import fr.gouv.vitamui.iam.server.configuration.ConfigurationService;
 import fr.gouv.vitamui.iam.server.customer.config.CustomerInitConfig;
 import fr.gouv.vitamui.iam.server.customer.dao.CustomerRepository;
 import fr.gouv.vitamui.iam.server.customer.domain.Customer;
@@ -126,9 +126,9 @@ public class TenantService extends AbstractResourceClientService<TenantDto, Tena
     private final CustomerRepository customerRepository;
     private final OwnerRepository ownerRepository;
     private final ProfileRepository profileRepository;
-    private final GroupService internalGroupService;
-    private final UserService internalUserService;
-    private final OwnerService internalOwnerService;
+    private final GroupService groupService;
+    private final UserService userService;
+    private final OwnerService ownerService;
     private final SecurityService securityService;
     private final IamLogbookService iamLogbookService;
     private final TenantConverter tenantConverter;
@@ -146,9 +146,9 @@ public class TenantService extends AbstractResourceClientService<TenantDto, Tena
         final CustomerRepository customerRepository,
         final OwnerRepository ownerRepository,
         final ProfileRepository profileRepository,
-        final GroupService internalGroupService,
-        final UserService internalUserService,
-        final OwnerService internalOwnerService,
+        final GroupService groupService,
+        final UserService userService,
+        final OwnerService ownerService,
         final SecurityService securityService,
         final IamLogbookService iamLogbookService,
         final TenantConverter tenantConverter,
@@ -164,9 +164,9 @@ public class TenantService extends AbstractResourceClientService<TenantDto, Tena
         this.customerRepository = customerRepository;
         this.ownerRepository = ownerRepository;
         this.profileRepository = profileRepository;
-        this.internalGroupService = internalGroupService;
-        this.internalUserService = internalUserService;
-        this.internalOwnerService = internalOwnerService;
+        this.groupService = groupService;
+        this.userService = userService;
+        this.ownerService = ownerService;
         this.securityService = securityService;
         this.iamLogbookService = iamLogbookService;
         this.tenantConverter = tenantConverter;
@@ -188,14 +188,14 @@ public class TenantService extends AbstractResourceClientService<TenantDto, Tena
 
         profiles.add(
             EntityFactory.buildProfile(
-                ApiIamExternalConstants.HIERARCHY_PROFILE_NAME + " " + tenantIdentifier,
+                ApiIamConstants.HIERARCHY_PROFILE_NAME + " " + tenantIdentifier,
                 getNextSequenceId(SequencesConstants.PROFILE_IDENTIFIER),
-                ApiIamExternalConstants.HIERARCHY_PROFILE_DESCRIPTION,
+                ApiIamConstants.HIERARCHY_PROFILE_DESCRIPTION,
                 true,
-                ApiIamExternalConstants.ADMIN_LEVEL,
+                ApiIamConstants.ADMIN_LEVEL,
                 tenantIdentifier,
                 CommonConstants.HIERARCHY_PROFILE_APPLICATIONS_NAME,
-                ApiIamExternalConstants.getHierarchyRoles(),
+                ApiIamConstants.getHierarchyRoles(),
                 customerId
             )
         );
@@ -407,8 +407,8 @@ public class TenantService extends AbstractResourceClientService<TenantDto, Tena
                     tenant.setEnabled(CastUtils.toBoolean(entry.getValue()));
                     break;
                 case "ownerId":
-                    final OwnerDto oldOwner = internalOwnerService.getOne(tenant.getOwnerId(), Optional.empty());
-                    final OwnerDto newOwner = internalOwnerService.getOne(
+                    final OwnerDto oldOwner = ownerService.getOne(tenant.getOwnerId(), Optional.empty());
+                    final OwnerDto newOwner = ownerService.getOne(
                         CastUtils.toString(entry.getValue()),
                         Optional.empty()
                     );
@@ -490,7 +490,7 @@ public class TenantService extends AbstractResourceClientService<TenantDto, Tena
         if (isProof) {
             final Optional<Tenant> optTenant = tenantRepository.findByCustomerIdAndProofIsTrue(customerId);
             Assert.isTrue(
-                !optTenant.isPresent(),
+                optTenant.isEmpty(),
                 message + ": a proof tenant already exists for customerId: " + customerId
             );
         }
@@ -567,8 +567,8 @@ public class TenantService extends AbstractResourceClientService<TenantDto, Tena
     private void addAdminProfilesToAdminGroup(final String customerId, final List<Profile> profiles) {
         final String[] apps = { CommonConstants.HIERARCHY_PROFILE_APPLICATIONS_NAME };
 
-        final UserDto adminUserDto = internalUserService.getDefaultAdminUser(customerId);
-        final GroupDto adminGroupDto = internalGroupService.getOne(
+        final UserDto adminUserDto = userService.getDefaultAdminUser(customerId);
+        final GroupDto adminGroupDto = groupService.getOne(
             adminUserDto.getGroupId(),
             Optional.empty(),
             Optional.empty()
@@ -582,12 +582,12 @@ public class TenantService extends AbstractResourceClientService<TenantDto, Tena
                 .orElseThrow(
                     () ->
                         new ApplicationServerException(
-                            String.format("Profile not found for app %s and customer %s.", app, customerId)
+                            "Profile not found for app %s and customer %s.".formatted(app, customerId)
                         )
                 );
             adminGroupDto.getProfileIds().add(profile.getId());
         }
-        internalGroupService.updateProfilesById(adminGroupDto.getId(), adminGroupDto.getProfileIds());
+        groupService.updateProfilesById(adminGroupDto.getId(), adminGroupDto.getProfileIds());
     }
 
     public LogbookOperationsCommonResponseDto findHistoryById(final String id) throws VitamClientException {
@@ -599,7 +599,7 @@ public class TenantService extends AbstractResourceClientService<TenantDto, Tena
             .setApplicationSessionId(securityService.getApplicationId());
 
         final Optional<Tenant> tenant = getRepository().findById(id);
-        tenant.orElseThrow(() -> new NotFoundException(String.format("No tenant found with id : %s", id)));
+        tenant.orElseThrow(() -> new NotFoundException("No tenant found with id : %s".formatted(id)));
 
         LOGGER.info(
             "Tenant History EvIdAppSession : {} ",
@@ -795,9 +795,7 @@ public class TenantService extends AbstractResourceClientService<TenantDto, Tena
         }
         final List<Integer> wrongIdentifiers = identifiers.stream().filter(this::canAccessToTenant).toList();
         if (!wrongIdentifiers.isEmpty()) {
-            throw new NoRightsException(
-                String.format(TENANT_INSUFFICIENT_PERMISSION_MESSAGE, wrongIdentifiers.toString())
-            );
+            throw new NoRightsException(TENANT_INSUFFICIENT_PERMISSION_MESSAGE.formatted(wrongIdentifiers.toString()));
         }
     }
 
