@@ -64,23 +64,22 @@ import fr.gouv.vitamui.commons.security.client.dto.AuthUserDto;
 import fr.gouv.vitamui.commons.vitam.api.access.LogbookService;
 import fr.gouv.vitamui.commons.vitam.api.dto.LogbookOperationDto;
 import fr.gouv.vitamui.commons.vitam.api.dto.LogbookOperationsCommonResponseDto;
-import fr.gouv.vitamui.iam.client.CustomerRestClient;
-import fr.gouv.vitamui.iam.client.UserRestClient;
 import fr.gouv.vitamui.iam.common.dto.CustomerDto;
+import fr.gouv.vitamui.iam.openapiclient.CustomersApi;
+import fr.gouv.vitamui.iam.openapiclient.UsersApi;
 import fr.gouv.vitamui.iam.security.service.SecurityService;
 import fr.gouv.vitamui.ingest.common.dsl.VitamQueryHelper;
 import fr.gouv.vitamui.ingest.common.dto.ArchiveUnitDto;
+import jakarta.ws.rs.core.Response;
 import org.apache.commons.lang3.StringUtils;
 import org.odftoolkit.simple.TextDocument;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.core.io.InputStreamResource;
 import org.springframework.core.io.Resource;
 import org.springframework.http.ResponseEntity;
 import org.w3c.dom.Document;
 
-import javax.ws.rs.core.Response;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
@@ -110,9 +109,9 @@ public class IngestService {
 
     private final ObjectMapper objectMapper;
 
-    private final CustomerRestClient customerRestClient;
+    private final CustomersApi customersApi;
 
-    private final UserRestClient userRestClient;
+    private final UsersApi usersApi;
 
     private final IngestGeneratorODTFile ingestGeneratorODTFile;
 
@@ -120,14 +119,13 @@ public class IngestService {
 
     private final IngestAccessContractService ingestAccessContractService;
 
-    @Autowired
     public IngestService(
         final SecurityService securityService,
         final LogbookService logbookService,
         final ObjectMapper objectMapper,
         final IngestExternalClient ingestExternalClient,
-        final CustomerRestClient customerRestClient,
-        final UserRestClient userRestClient,
+        final CustomersApi customersApi,
+        final UsersApi usersApi,
         final IngestGeneratorODTFile ingestGeneratorODTFile,
         final IngestExternalParametersService ingestExternalParametersService,
         final IngestAccessContractService ingestAccessContractService
@@ -136,8 +134,8 @@ public class IngestService {
         this.ingestExternalClient = ingestExternalClient;
         this.logbookService = logbookService;
         this.objectMapper = objectMapper;
-        this.customerRestClient = customerRestClient;
-        this.userRestClient = userRestClient;
+        this.customersApi = customersApi;
+        this.usersApi = usersApi;
         this.ingestGeneratorODTFile = ingestGeneratorODTFile;
         this.ingestExternalParametersService = ingestExternalParametersService;
         this.ingestAccessContractService = ingestAccessContractService;
@@ -241,8 +239,8 @@ public class IngestService {
             String manifest = "";
             Response response = ingestExternalClient.downloadObjectAsync(vitamContext, id, IngestCollection.MANIFESTS);
             Object entity = response.getEntity();
-            if (entity instanceof InputStream) {
-                Resource resource = new InputStreamResource((InputStream) entity);
+            if (entity instanceof InputStream stream) {
+                Resource resource = new InputStreamResource(stream);
                 manifest = ingestGeneratorODTFile.resourceAsString(resource).replaceAll(ILLEGAL_CHARACTERS, "");
             }
             LOGGER.info("Manifest EvIdAppSession : {} ", vitamContext.getApplicationSessionId());
@@ -262,8 +260,8 @@ public class IngestService {
                 IngestCollection.ARCHIVETRANSFERREPLY
             );
             Object entity = response.getEntity();
-            if (entity instanceof InputStream) {
-                Resource resource = new InputStreamResource((InputStream) entity);
+            if (entity instanceof InputStream stream) {
+                Resource resource = new InputStreamResource(stream);
                 atr = ingestGeneratorODTFile.resourceAsString(resource).replaceAll(ILLEGAL_CHARACTERS, "");
             }
             LOGGER.info("ATR EvIdAppSession : {} ", vitamContext.getApplicationSessionId());
@@ -278,13 +276,13 @@ public class IngestService {
         try {
             LOGGER.info("Generate ODT Report : get Manifest and ATR of the operation ID : {} ", id);
             VitamContext vitamContext = ingestExternalParametersService.buildVitamContextFromExternalParam();
-            AuthUserDto me = userRestClient.getMe(securityService.getHttpContext());
+            AuthUserDto me = usersApi.getMe();
             if (me == null || StringUtils.isEmpty(me.getCustomerId())) {
                 throw new IngestFileGenerationException(
                     "Could not retrieve current user or his customer id to generate the document"
                 );
             }
-            CustomerDto myCustomer = customerRestClient.getMyCustomer(securityService.getHttpContext());
+            CustomerDto myCustomer = customersApi.getMyCustomer();
             Resource customerLogo = null;
             Document atr = ingestGeneratorODTFile.convertStringToXMLDocument(getAtrAsString(vitamContext, id));
             Document manifest = ingestGeneratorODTFile.convertStringToXMLDocument(
@@ -299,9 +297,7 @@ public class IngestService {
             }
 
             if (myCustomer.isHasCustomGraphicIdentity()) {
-                customerLogo = customerRestClient
-                    .getLogo(securityService.getHttpContext(), myCustomer.getId(), AttachmentType.HEADER)
-                    .getBody();
+                customerLogo = customersApi.getLogo(myCustomer.getId(), AttachmentType.HEADER.value());
             }
             List<ArchiveUnitDto> archiveUnitDtoList = ingestGeneratorODTFile.getValuesForDynamicTable(atr, manifest);
 
