@@ -40,9 +40,10 @@ package fr.gouv.vitamui.pastis.common.util;
 import fr.gouv.vitamui.pastis.common.dto.ElementRNG;
 import lombok.Getter;
 import org.xml.sax.Attributes;
-import org.xml.sax.SAXException;
 import org.xml.sax.helpers.DefaultHandler;
 
+import java.util.Arrays;
+import java.util.Optional;
 import java.util.Stack;
 
 public class PastisSAX2Handler extends DefaultHandler {
@@ -50,8 +51,11 @@ public class PastisSAX2Handler extends DefaultHandler {
     @Getter
     private ElementRNG elementRNGRoot;
 
-    boolean isValue;
-    private Stack<ElementRNG> stackRNG = new Stack<>();
+    @Getter
+    private String sedaVersion;
+
+    private boolean isValue;
+    private final Stack<ElementRNG> stackRNG = new Stack<>();
     private boolean isInDocumentationTag;
     private StringBuilder documentationContent;
 
@@ -60,8 +64,9 @@ public class PastisSAX2Handler extends DefaultHandler {
      * This method is called everytime the parser gets an open tag
      * Identifies which tag has being opened at time by assiging a new flag
      */
+    @Override
     public void startElement(String nameSpace, String localName, String qName, Attributes attr) {
-        //cette variable contient le nom du nœud qui a créé l'événement
+        // cette variable contient le nom du nœud qui a créé l'événement
         // If node not a grammar tag or start tag
         if (!("grammar".equals(localName) || "start".equals(localName))) {
             // If node is ArchiveTransfer
@@ -89,12 +94,35 @@ public class PastisSAX2Handler extends DefaultHandler {
         if (qName.equalsIgnoreCase("xsd:documentation")) {
             isInDocumentationTag = true;
         }
+
+        if ("grammar".equals(localName)) {
+            final String defaultXmlNamespace = attr.getValue("xmlns");
+            final String sedaXmlNamespace = attr.getValue("xmlns:seda");
+            final String namespace = attr.getValue("ns");
+
+            if (sedaVersion == null && defaultXmlNamespace != null) sedaVersion = Arrays.stream(
+                defaultXmlNamespace.split(":")
+            )
+                .reduce((first, second) -> second)
+                .orElse(null);
+            if (sedaVersion == null && sedaXmlNamespace != null) sedaVersion = Arrays.stream(
+                sedaXmlNamespace.split(":")
+            )
+                .reduce((first, second) -> second)
+                .orElse(null);
+            if (sedaVersion == null && namespace != null) sedaVersion = Arrays.stream(namespace.split(":"))
+                .reduce((first, second) -> second)
+                .orElse(null);
+            // Remove the initial 'v'
+            sedaVersion = Optional.ofNullable(sedaVersion).map(v -> v.substring(1)).orElse(null);
+        }
     }
 
     /**
      * Actions à réaliser lors de la détection de la fin d'un élément.
      */
-    public void endElement(String nameSpace, String localName, String qName) throws SAXException {
+    @Override
+    public void endElement(String nameSpace, String localName, String qName) {
         if (qName.equalsIgnoreCase("xsd:documentation")) {
             isInDocumentationTag = false;
         }
@@ -106,6 +134,7 @@ public class PastisSAX2Handler extends DefaultHandler {
     /**
      * Actions à réaliser au début du document.
      */
+    @Override
     public void startDocument() {
         elementRNGRoot = new ElementRNG();
         elementRNGRoot.setName("ArchiveTransfer");
@@ -114,10 +143,10 @@ public class PastisSAX2Handler extends DefaultHandler {
     }
 
     /**
-     * Actions to perform when tag content is reached (Data between '< />' )
+     * Actions to perform when tag content is reached (Data between '< />')
      */
     @Override
-    public void characters(char[] caracteres, int start, int length) throws SAXException {
+    public void characters(char[] caracteres, int start, int length) {
         if (isInDocumentationTag) {
             documentationContent.append(new String(caracteres, start, length));
             stackRNG.lastElement().setValue(documentationContent.toString());
